<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
	register_activation_hook( __FILE__, 'rwmb_check_php_version' );

	/**
	 * Display notice for old PHP version.
	 */
	function rwmb_check_php_version() {
		if ( version_compare( phpversion(), '5.3', '<' ) ) {
			die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
		}
	}




	require_once dirname( __FILE__ ) . '/inc/loader.php';
	$rwmb_loader = new RWMB_Loader();
	$rwmb_loader->init();


	add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

	$prefix = '_cmb_';


  // Open Code

    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Video Link',
                'desc' => 'Video Link',
                'default' => '',
                'id' => $prefix . 'video_link',
                'type' => 'text'
            ),
            array(
                'name' => 'Audio Iframe',
                'desc' => 'Audio Iframe',
                'default' => '',
                'id' => $prefix . 'audio_iframe',
                'type' => 'text'
            ),
            array(
                'name' => 'Image:',
                'desc' => 'Show in widget Recent Posts',
                'default' => '',
                'id' => $prefix . 'image123',
                'type' => 'file'
            ),
            array(
                'name' => 'Image:',
                'desc' => 'Show in Blog Home 1',
                'default' => '',
                'id' => $prefix . 'featured_image_3',
                'type' => 'file'
            ),
            array(
                'name' => 'Image:',
                'desc' => 'Show in Blog Home 2',
                'default' => '',
                'id' => $prefix . 'featured_image_4',
                'type' => 'file'
            ),
              array(
                'name' => 'Image:',
                'desc' => 'Show in Blog Home 3',
                'default' => '',
                'id' => $prefix . 'featured_image_5',
                'type' => 'file'
            ),
            array(
                'name' => 'Link share facebook:',
                'desc' => 'Input Link share facebook',
                'id'   => $prefix . 'single_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share twitter:',
                'desc' => 'Input Link share twitter',
                'id'   => $prefix . 'single_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share instagram:',
                'desc' => 'Input Link share instagram',
                'id'   => $prefix . 'single_instagram',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share google plus:',
                'desc' => 'Input Link share google plus',
                'id'   => $prefix . 'single_google_plus',
                'type'    => 'text',
            ),
        
            array(
                'name' => 'Link share vimeo:',
                'desc' => 'Input Link share vimeo',
                'id'   => $prefix . 'single_vimeo',
                'type'    => 'text',
            ),

        )
    );

 $meta_boxes[] = array(
        'id'         => 'testimonial_setting',
        'title'      => 'testimonial Setting',
        'pages'      => array('testimonial'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                    'name' => 'Job:',
                    'desc' => 'Job',
                    'default' => '',
                    'id' => $prefix . 'text123',
                    'type' => 'text'
            ),
            array(
                    'name' => 'Image:',
                    'desc' => 'Show in Testimonials 3',
                    'default' => '',
                    'id' => $prefix . 'image1234',
                    'type' => 'file'
            ),
             

        )
    );


$meta_boxes[] = array(
        'id'         => 'services_setting',
        'title'      => 'services Setting',
        'pages'      => array('services'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
        array(
                'name' => 'Excerpt:',
                'desc' => 'Excerpt',
                'default' => '',
                'id' => $prefix . 'excerpt',
                'type' => 'text'
            ), 
        array(
                'name' => 'Image:',
                'desc' => 'Show in Services 2, Services 3',
                'default' => '',
                'id' => $prefix . 'image112',
                'type' => 'file'
            ), 
        )
    );
$meta_boxes[] = array(
        'id'         => 'portfolio_setting',
        'title'      => 'Gallery Setting',
        'pages'      => array('portfolio'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                    'name' => 'Description:',
                    'desc' => 'Description',
                    'default' => '',
                    'id' => $prefix . 'excerpt',
                    'type' => 'text'
            ),
            array(
                    'name' => 'Image 1:',
                    'desc' => 'Show in Gallery 1',
                    'default' => '',
                    'id' => $prefix . 'image111',
                    'type' => 'file'
            ), 
            array(
                    'name' => 'Image 2:',
                    'desc' => 'Show in Gallery 2',
                    'default' => '',
                    'id' => $prefix . 'image121',
                    'type' => 'file'
            ), 

               array(
                    'name' => 'Gallery 3:',
                    'desc' => 'Show in Gallery 3',
                    'default' => '',
                    'id' => $prefix . 'featured_image_8',
                    'type' => 'file'
            ), 

             array(
                    'name' => 'Gallery 4:',
                    'desc' => 'Show in Gallery 4',
                    'default' => '',
                    'id' => $prefix . 'featured_image_7',
                    'type' => 'file'
            ), 

            array(
                    'name' => 'Clients:',
                    'desc' => 'Clients',
                    'default' => '',
                    'id' => $prefix . 'cliends',
                    'type' => 'text'
            ),
            array(
                    'name' => 'Date:',
                    'desc' => 'Date',
                    'default' => '',
                    'id' => $prefix . 'date',
                    'type' => 'text'
            ),
            array(
                    'name' => 'Role:',
                    'desc' => 'Role',
                    'default' => '',
                    'id' => $prefix . 'role',
                    'type' => 'text'
            ),
            array(
                    'name' => 'View Site:',
                    'desc' => 'View Site',
                    'default' => '',
                    'id' => $prefix . 'view_site',
                    'type' => 'text'
            ),
            array(
                'name' => 'Link share facebook:',
                'desc' => 'Input Link share facebook',
                'id'   => $prefix . 'single_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share twitter:',
                'desc' => 'Input Link share twitter',
                'id'   => $prefix . 'single_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share linkedin:',
                'desc' => 'Input Link share linkedin',
                'id'   => $prefix . 'single_linkedin',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share youtube:',
                'desc' => 'Input Link share youtube',
                'id'   => $prefix . 'single_youtube',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share behance:',
                'desc' => 'Input Link share behance',
                'id'   => $prefix . 'single_behance',
                'type'    => 'text',
            ),
            
        )
    );
    
$meta_boxes[] = array(
        'id'         => 'team_setting',
        'title'      => 'team Setting',
        'pages'      => array('team'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Job',
                'desc' => 'Job',
                'default' => '',
                'id' => $prefix . 'team_job',
                'type' => 'text'
            ), 
            array(
                'name' => 'Link Facebook:',
                'desc' => 'Input link Facebook',
                'id'   => $prefix . 'team_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Twitter:',
                'desc' => 'Input link Twitter',
                'id'   => $prefix . 'team_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Linkedin:',
                'desc' => 'Input link Linkedin',
                'id'   => $prefix . 'team_linkedin',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Youtube:',
                'desc' => 'Input link Youtube',
                'id'   => $prefix . 'team_youtube',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Behance:',
                'desc' => 'Input link Behance',
                'id'   => $prefix . 'team_behance',
                'type'    => 'text',
            ),
   
        )
    );
$meta_boxes[] = array(
        'id'         => 'product_setting',
        'title'      => 'product Setting',
        'pages'      => array('product'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Link share facebook:',
                'desc' => 'Input Link share facebook',
                'id'   => $prefix . 'single_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share twitter:',
                'desc' => 'Input Link share twitter',
                'id'   => $prefix . 'single_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share behance:',
                'desc' => 'Input Link share behance',
                'id'   => $prefix . 'single_behance',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share linkedin:',
                'desc' => 'Input Link share linkedin',
                'id'   => $prefix . 'single_linkedin',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share youtube:',
                'desc' => 'Input Link share youtube',
                'id'   => $prefix . 'single_youtube',
                'type'    => 'text',
            ),
        )
    );
    return $meta_boxes;
});
}