<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsaboutServices extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-Services-about';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Pages About - Service Widget', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-favorite';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'about' ];
    }

    public function get_keywords() {
        return [ 'services' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Services', 'bdevs-elementor' ),
            ]   
        );

        $this->add_control(
            'background',
            [
                'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  

        $this->add_control(
            'image',
            [
                'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  



        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('Heading', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->add_control(
            'content',
            [
                'label'       => __( 'Content', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'       => __('This is Content', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->end_controls_section();      

        $this->start_controls_section(
            'section_content_item',
            [
                'label' => esc_html__( 'Services Items', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [   

                     [
                        'name'    => 'image',
                        'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'dynamic' => [ 'active' => true ],
                        'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
						 'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],

                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'This is Title' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],


                    [
                        'name'        => 'number',
                        'label'       => esc_html__( 'Number', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Number' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                                                          

                    [
                        'name'        => 'description',
                        'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'This is Description' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],      


                    [
                        'name'        => 'link',
                        'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],  


                    [
                        'name'        => 'button',
                        'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                                                                                                                                   
                ],
            ]
        );  
    $this->end_controls_section();  

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); ?>
        <!-- we-works-area-start -->
        <div class="we-works-area pt-120 pb-95" style="background-image:url(<?php print wp_kses_post($settings['background']['url']); ?>)">
            <div class="container">
                <div class="row">
                    <div class="col-xl-6 col-lg-6 offset-lg-3 offset-xl-3">
                        <div class="section-title text-center section-title-cap mb-90">
                            <div class="section-icon">
                                <img src="<?php print wp_kses_post($settings['image']['url']); ?>" alt="">
                            </div>
                            <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                            <p><?php print wp_kses_post($settings['content']); ?></p>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <?php  foreach ( $settings['tabs'] as $item ):?>
                        <div class="col-xl-4 col-lg-4 col-md-6">
                            <div class="we-works-wrapper text-center mb-30">
                                <div class="we-works-icon">
                                    <img src="<?php print wp_kses_post($item['image']['url']); ?>" alt="">
                                    <span class="works-tag"><?php print wp_kses_post($item['number']); ?></span>
                                </div>
                                <div class="we-works-text">
                                    <h3><?php print wp_kses_post($item['title']); ?></h3>
                                    <p><?php print wp_kses_post($item['description']); ?></p>
                                    <a class="btn" href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['button']); ?></a>
                                </div>
                            </div>
                        </div>
                    <?php endforeach;?>
                </div>
            </div>
        </div>
        <?php
    }

}