<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsfaqQuestionandanswer extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-Questionandanswer-faq';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Question and Answer', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'faq' ];
	}

	public function get_keywords() {
		return [ 'questionandanswer' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Question And Answer ', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

			$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Description', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->end_controls_section();


	 $this->start_controls_section(
            'section_content_item',
            [
                'label' => esc_html__( ' Question And Answer Items', 'bdevs-elementor' ),
            ]
        );
		 $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [

                    [
                        'name'        => 'headingone',
                        'label'       => esc_html__( 'Heading One', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'This is Heading One' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],

                    [
                        'name'        => 'collapse',
                        'label'       => esc_html__( 'Collapse', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'This is Collapse' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],

                    [
                    	'name'        => 'target',
                    	'label'       => esc_html__( 'Target', 'bdevs-elementor' ),
                    	'type'        => Controls_Manager::TEXT,
                    	'dynamic'     => [ 'active' => true ],
                    	'default'     => esc_html__( 'This is Target' , 'bdevs-elementor' ),
                    	'label_block' => true,
                    ],

                    [
                    	'name'        => 'right_wrong',
                    	'label'       => esc_html__( 'Right Wrong', 'bdevs-elementor' ),
                    	'type'        => Controls_Manager::TEXT,
                    	'dynamic'     => [ 'active' => true ],
                    	'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                    	'label_block' => true,
                    ],

                    [
                    	'name'        => 'controls',
                    	'label'       => esc_html__( 'Controls', 'bdevs-elementor' ),
                    	'type'        => Controls_Manager::TEXT,
                    	'dynamic'     => [ 'active' => true ],
                    	'default'     => esc_html__( 'This is Controls' , 'bdevs-elementor' ),
                    	'label_block' => true,
                    ],

                    [
                    	'name'        => 'show',
                    	'label'       => esc_html__( 'Show', 'bdevs-elementor' ),
                    	'type'        => Controls_Manager::TEXT,
                    	'dynamic'     => [ 'active' => true ],
                    	'default'     => esc_html__( 'This is Show' , 'bdevs-elementor' ),
                    	'label_block' => true,
                    ],


                    [
                    	'name'        => 'title',
                    	'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
                    	'type'        => Controls_Manager::TEXT,
                    	'dynamic'     => [ 'active' => true ],
                    	'default'     => esc_html__( 'This is Title' , 'bdevs-elementor' ),
                    	'label_block' => true,
                    ],


                    [
                    	'name'        => 'content',
                    	'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
                    	'type'        => Controls_Manager::TEXTAREA,
                    	'dynamic'     => [ 'active' => true ],
                    	'default'     => esc_html__( 'This is Content' , 'bdevs-elementor' ),
                    	'label_block' => true,
                    ],
                ],
            ]
        );  
    $this->end_controls_section();  
		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>

  <!-- faq -->
    <section id="faq" class="faq-area pt-115 pb-100">
        <div class="container">
            <div class="row">
                <div class="col-xl-6 col-lg-6 offset-lg-3 offset-xl-3">
                    <div class="section-title text-center mb-70">
                        <div class="section-icon">
                            <img src="<?php print wp_kses_post($settings['icon']['url']); ?>" alt="">
                        </div>
                        <h1 class="text-capitalize"><?php print wp_kses_post($settings['heading']); ?></h1>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-xl-12">
                    <div class="faq-box">
                        <div id="accordion">
                        	<?php foreach ( $settings ['tabs'] as $item ): ?>
                            <div class="card">
                                <div class="card-header" id="<?php print wp_kses_post($item['headingone']); ?>">
                                    <h5 class="mb-0">
                                        <a href="#" class="btn-link" data-toggle="<?php print wp_kses_post($item['collapse']); ?>" data-target="<?php print wp_kses_post($item['target']); ?>"
                                            aria-expanded="<?php print wp_kses_post($item['right_wrong']); ?>" aria-controls="<?php print wp_kses_post($item['controls']); ?>">
                                            <?php print wp_kses_post($item['title']); ?>
                                        </a>
                                    </h5>
                                </div>
                                <div id="<?php print wp_kses_post($item['controls']); ?>" class="<?php print wp_kses_post($item['show']); ?>" aria-labelledby="<?php print wp_kses_post($item['headingone']); ?>"
                                    data-parent="#accordion">
                                    <div class="card-body">
                                        <p><?php print wp_kses_post($item['content']); ?></p>
                                    </div>
                                </div>
                            </div>
                       <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
	<?php
	}

}