<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome1Features extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-features-home-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Features-Home-1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Contact widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-form-horizontal';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Contact widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-1'];
	}

	public function get_keywords() {
		return [ 'features',];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_item',
			[
				'label' => esc_html__( 'Features ', 'bdevs-elementor' ),
			]
		); 

		$this->add_control(
			'background',
			[
				'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

			$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);
		$this->end_controls_section();

			$this->start_controls_section(
				'section_content_items',
				[
					'label' => esc_html__( 'Features Items', 'bdevs-elementor' ),
				]
			);

      $this->add_control(
          'tabs',
          [
              'label' => esc_html__( 'Items', 'bdevs-elementor' ),
              'type' => Controls_Manager::REPEATER,
              'fields' => [   

              	[
              		'name'    => 'image',
              		'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
              		'type'    => Controls_Manager::MEDIA,
              		'dynamic' => [ 'active' => true ],
					'default'     => esc_html__( '' , 'bdevs-elementor' ),
              	],


              	[
              		'name'    => 'image_icon',
              		'label'   => esc_html__( 'Image Icon', 'bdevs-elementor' ),
              		'type'    => Controls_Manager::MEDIA,
              		'dynamic' => [ 'active' => true ],
					'default'     => esc_html__( '' , 'bdevs-elementor' ),
              	],

              	[
              		'name'        => 'number',
              		'label'       => esc_html__( 'Number', 'bdevs-elementor' ),
              		'type'        => Controls_Manager::TEXT,
              		'dynamic'     => [ 'active' => true ],
              		'default'     => esc_html__( 'Number' , 'bdevs-elementor' ),
              		'label_block' => true,
              	],


              	[
              		'name'        => 'title',
              		'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
              		'type'        => Controls_Manager::TEXT,
              		'dynamic'     => [ 'active' => true ],
              		'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
              		'label_block' => true,
              	],

              	[
              		'name'        => 'description',
              		'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
              		'type'        => Controls_Manager::TEXTAREA,
              		'dynamic'     => [ 'active' => true ],
              		'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),
              		'label_block' => true,
              	],
                 
              ],
          ]
      );

      $this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
           
		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
	 <!-- features-area-start -->
            <div class="features-area pt-115 pb-85" style="background-image:url(<?php print wp_kses_post($settings['background']['url']); ?>)">
                <div class="container">

                    <div class="row">
                        <div class="col-xl-7">
                            <div class="section-title mb-70">
                                <span><?php print wp_kses_post($settings['subheading']); ?></span>
                                <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                    	<?php foreach ( $settings ['tabs'] as $item ): ?>
                        <div class="col-xl-3 col-lg-3 col-md-6">
                            <div class="features-wrapper mb-30">
                                <div class="features-img">
                                    <img src="<?php print wp_kses_post($item['image']['url']); ?>" alt="">
                                    <span class="features-tag"><?php print wp_kses_post($item['number']); ?></span>
                                    <div class="angle-icon">
                                    	<?php if ( '' !== $item['image_icon']['url'] ): ?>
                                        <img src="<?php print wp_kses_post($item['image_icon']['url']); ?>" alt="">
                                    <?php endif;  ?>
                                    </div>
                                </div>
                                <div class="features-text">
                                    <h3><?php print wp_kses_post($item['title']); ?></h3>
                                    <p><?php print wp_kses_post($item['description']); ?></p>
                                </div>
                            </div>
                        </div>
                      <?php endforeach; ?>
                    </div>
                </div>
            </div>
            <!-- features-area-end -->

	<?php
	}

}