<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome1Product extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-product-home-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Product Home-1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-list';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-1' ];
	}

	public function get_keywords() {
		return [ 'product' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
			$this->start_controls_section(
				'section_content_item',
				[
					'label' => esc_html__( 'Product Image', 'bdevs-elementor' ),
				]
			);

			$this->add_control(
					'image',
					[
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
					]
				);	

			$this->add_control(
					'image_2',
					[
						'label'   => esc_html__( 'Image 2', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
					]
				);	


			$this->add_control(
				'image_3',
				[
					'label'   => esc_html__( 'Image 3', 'bdevs-elementor' ),
					'type'    => Controls_Manager::MEDIA,
					'dynamic' => [ 'active' => true ],
					'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
				]
			);	

			$this->add_control(
				'image_4',
				[
					'label'   => esc_html__( 'Image 4', 'bdevs-elementor' ),
					'type'    => Controls_Manager::MEDIA,
					'dynamic' => [ 'active' => true ],
					'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
				]
			);	


		


			
	      $this->end_controls_section();	


		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Product', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'icon',
			[
				'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'link',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Link Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$post_number = $settings['post_number'];
	    $order = $settings['post_order'];
	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'product',  'orderby' => 'ID', 'order' => $order));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'product',  'orderby' => 'ID', 'order' => $order);	
	   	?>
	   	  <!-- product-area-start -->
            <div class="product-area pos-relative pt-120 pb-120 woocommerce">
                <div class="shape d-none d-xl-block">
                    <div class="shape-item pro-01 bounce-animate"><img src="<?php print wp_kses_post($settings['image']['url']); ?>" alt=""></div>
                    <div class="shape-item pro-02 bounce-animate"><img src="<?php print wp_kses_post($settings['image_2']['url']); ?>" alt=""></div>
                    <div class="shape-item pro-03 bounce-animate"><img src="<?php print wp_kses_post($settings['image_3']['url']); ?>" alt=""></div>
                    <div class="shape-item pro-04 bounce-animate"><img src="<?php print wp_kses_post($settings['image_4']['url']); ?>" alt=""></div>
                </div>
                <div class="container">
                    <div class="row">
                       <div class="col-xl-6 col-lg-6 offset-lg-3 offset-xl-3">
                            <div class="section-title text-center mb-70">
                                <div class="section-icon">
                                    <img src="<?php print wp_kses_post($settings['icon']['url']); ?>" alt="">
                                </div>
                                <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                                <p><?php print wp_kses_post($settings['content']); ?></p>
                            </div>
                         </div>
                     </div>
                     <div class="row">
                     	<?php
	   				$args = new \WP_Query(array(   
	   					'post_type' => 'product', 
	   				));  
	   				while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
	   					global $product;
	   					$rating_count = $product->get_rating_count();
	   					$review_count = $product->get_review_count();
	   					$average      = $product->get_average_rating();
	   					$display_price         = $product->get_display_price();
	   					$display_regular_price = $product->get_display_price( $product->get_regular_price() );
	   					$xxx         = ($display_regular_price - $display_price) / $display_regular_price * 100;
	   					?>
                        <div class="col-xl-3 col-lg-3 col-md-6">
                            <div class="product-wrapper text-center mb-30">
                                <div class="product-img">
                                    <a href="#"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
                                </div>
                                
                                	<?php if($xxx!==0) { ;?>
                                		<div class="on-sale">
                                			<span>-<?php echo floor($xxx); ?>%</span>
                                		</div>
                                		<?php } ?>
                                
                                <div class="product-text">
                                    <h4><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h4>
                                    <div class="pro-rating">
                                       <div class="woocommerce-product-rating" itemprop="aggregateRating" itemscope itemtype="http://schema.org/AggregateRating">
                <div class="star-rating" title="<?php printf( __( 'Rated %s out of 5', 'woocommerce' ), $average ); ?>">
                      <span style="width:<?php echo ( ( $average / 5 ) * 100 ); ?>%">
                          <strong itemprop="ratingValue" class="rating"><?php echo esc_html( $average ); ?></strong> <?php printf( __( 'out of %s5%s', 'woocommerce' ), '<span itemprop="bestRating">', '</span>' ); ?>
                          <?php printf( _n( 'based on %s customer rating', 'based on %s customer ratings', $rating_count, 'woocommerce' ), '<span itemprop="ratingCount" class="rating">' . $rating_count . '</span>' ); ?>
                      </span>
                  </div>
                </div>
                                    </div>
                                    <div class="pro-price">
                                        <span><?php echo $product->get_price_html(); ?></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; wp_reset_postdata(); ?>
                     </div>
                     <div class="row">
                         <div class="col-xl-12">
                             <div class="product-button mt-30 text-center">
                                 <a class="btn" href="<?php print wp_kses_post($settings['link']); ?>"><?php print wp_kses_post($settings['button']); ?></a>
                             </div>
                         </div>
                     </div>
                </div>
            </div>
            <!-- product-area-end -->
	<?php
	}

}