<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome1Team extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-team-home-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team home-1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return ['home-1'];
	}

	public function get_keywords() {
		return [ 'team' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Team', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'background',
			[
				'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);	

			$this->add_control(
			'icon',
			[
				'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);	


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		
		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'content_2',
			[
				'label'       => __( 'Description Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Description Content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'link',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('#', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	
		$this->end_controls_section();	


		$this->start_controls_section(
			'section_content_items',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items ', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [   

					[
						'name'    => 'image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],

					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'description',
						'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'facebook',
						'label'       => esc_html__( 'Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://facebook.com' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'twitter',
						'label'       => esc_html__( 'Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://twitter.com' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'linkedin',
						'label'       => esc_html__( 'Linkedin', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://Linkedin.com' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'youtube',
						'label'       => esc_html__( 'YouTube', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://youtube.com' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'bahance',
						'label'       => esc_html__( 'Behance', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://Behance.com' , 'bdevs-elementor' ),
						'label_block' => true,
					],

				],
			]
		);

		$this->end_controls_section();	
		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>
		  <!-- team-area-start -->
            <div class="team-area pt-120 pb-90">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-5 col-lg-5">
                            <div class="team-content mb-30" style="background-image:url(<?php print wp_kses_post($settings['background']['url']); ?>)">
                                <div class="section-title mb-65">
                                    <div class="section-icon">
                                        <img src="<?php print wp_kses_post($settings['icon']['url']); ?>" alt="">
                                    </div>
                                    <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                                    <p><?php print wp_kses_post($settings['content']); ?></p>
                                </div>
                               <p><?php print wp_kses_post($settings['content_2']); ?></p>
                            <a class="btn" href="<?php print wp_kses_post($settings['link']); ?>"><?php print wp_kses_post($settings['button']); ?></a>
                            </div>
                        </div>
                        <div class="col-xl-7 col-lg-7">
                            <div class="row">
                            	<?php foreach ( $settings ['tabs'] as $item ): ?>
                            	<div class="col-xl-6 col-lg-6 col-md-6">
                            		<div class="team-wrapper mb-30">
                            			<div class="team-img">
                            				<img src="<?php print wp_kses_post($item['image']['url']); ?>" alt="">
                            				<div class="team-text">
                            					<h4><?php print wp_kses_post($item['title']); ?></h4>
                            					<span><?php print wp_kses_post($item['description']); ?></span>
                            					<div class="team-social-icon">
                            						<a href="<?php print wp_kses_post($item['facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
                            						<a href="<?php print wp_kses_post($item['twitter']); ?>"><i class="fab fa-twitter"></i></a>
                            						<a href="<?php print wp_kses_post($item['linkedin']); ?>"><i class="fab fa-linkedin-in"></i></a>
                            						<a href="<?php print wp_kses_post($item['youtube']); ?>"><i class="fab fa-youtube"></i></a>
                            						<a href="<?php print wp_kses_post($item['behance']); ?>"><i class="fab fa-behance"></i></a>
                            					</div>
                            				</div>
                            			</div>
                            		</div>
                            	</div>
                        	<?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
       <!-- team-area-end -->
	<?php
	}
}