<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome2Blog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog-home-2';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog Home-2', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-list';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-2' ];
	}

	public function get_keywords() {
		return [ 'blog' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Blog', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
					'background',
					[
						'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
					]
				);	

			$this->add_control(
			'icon',
			[
				'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('This is Content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$post_number = $settings['post_number'];
	    $order = $settings['post_order'];
	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order);	
	   	?>


	   	  <!-- blog-area-start -->
            <div class="blog-area  pt-120 pb-90" style="background-image:url(<?php print wp_kses_post($settings['background']['url']); ?>)">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 col-lg-6 offset-lg-3 offset-xl-3">
                            <div class="section-title section-title-cap text-center mb-65">
                                <div class="section-icon section1-icon">
                                    <img src="<?php print wp_kses_post($settings['icon']['url']); ?>" alt="">
                                </div>
                                <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                                <p><?php print wp_kses_post($settings['content']); ?></p>
                            </div>
                        </div>
                    </div>
                    <div class="row">

                    		<?php
	   				$args = new \WP_Query(array(   
	   					'post_type' => 'post', 
	   				));  
	   				while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
	   					?>
                <div class="col-xl-6 col-lg-6 mb-30">
                    <div class="blog-bg">
                        <div class="row">
                            <div class="col-xl-6 col-lg-12 col-md-6">
                                <div class="blog-img">
                  <?php $featured_image_4 = get_post_meta(get_the_ID(),'_cmb_featured_image_4', true); ?>
                   <a href="blog-details.html"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt=""></a>
                                </div>
                            </div>
                            <div class="col-xl-6 col-lg-12  col-md-6">
                                <div class="blog-text">
                                    <div class="blog-meta">
                                        <span> <i class="dripicons-calendar"></i><?php the_time(get_option('date_format')); ?></span>
                                        <span> <i class="dripicons-heart"></i><?php comments_number( esc_html__('0 Comments' , 'orgafe') , esc_html__('1 Comment' , 'orgafe' ), esc_html__('% Comments' , 'orgafe')); ?></span>
                                    </div>
                                    <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                                    <p><?php if(isset($orgafe_redux_demo['blog_excerpt'])&& $orgafe_redux_demo['blog_excerpt']!=''){?>
									<?php echo esc_attr(orgafe_excerpt($orgafe_redux_demo['blog_excerpt'])); ?>
								<?php }else{?>
									<?php echo esc_attr(orgafe_excerpt(40));}?></p>
                                    <a class="btn" href="<?php the_permalink(); ?>"><?php if(isset($orgafe_redux_demo['read_more'])){?>
										<?php echo wp_specialchars_decode(esc_attr($orgafe_redux_demo['read_more']));?>
										<?php }else{?><?php echo esc_html__( 'Read More ', 'orgafe' );  } ?></a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
             <?php endwhile; wp_reset_postdata(); ?>
            </div>
        </div>
    </div>
    <!-- blog-area-end -->
	<?php
	}

}