<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome2Brand extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-Brand-home-2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Brand - Home- 2', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-slides';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'home-2' ];
    }

    public function get_keywords() {
        return [ 'brand', 'carousel' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Brand', 'bdevs-elementor' ),
            ]   
        );

        $this->add_control(
            'logo',
            [
                'label'   => esc_html__( 'Logo', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  


        $this->add_control(
            'facebook',
            [
                'label'       => __( 'Facebook', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('https://facebook.com', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->add_control(
            'twitter',
            [
                'label'       => __( 'Twitter', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('https://twitter.com', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  


        $this->add_control(
            'youtube',
            [
                'label'       => __( 'Youtube', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('https://Youtube.com', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->add_control(
            'behance',
            [
                'label'       => __( 'Behance', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('https://behance.com', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->add_control(
            'linkedin',
            [
                'label'       => __( 'Linkedin', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('https://linkedin.com', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->end_controls_section();  


        $this->start_controls_section(
            'section_content_items',
            [
                'label' => esc_html__( 'Brand items', 'bdevs-elementor' ),
            ]
        );

        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [   
                    
                    [
                        'name'    => 'image',
                        'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
                    ],
                    
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        extract($settings);
        ?>
  <!-- brand-area-satrt -->
            <div class="brand-area pt-50 grey1-bg">
                <div class="container">
                    <div class="brand-bg pb-50">
                        <div class="row">
                            <div class="col-xl-3 col-lg-3 col-md-3">
                                <div class="bottom-logo">
                                    <a href="<?php echo esc_url(home_url('/')); ?>"><img src="<?php print wp_kses_post($settings['logo']['url']); ?>" alt=""></a>
                                </div>
                            </div>
                            <div class="col-xl-6 col-lg-5 col-md-4">
                                <div class="brand-wrapper">
                                    <div class="brand-active owl-carousel">
                                        <?php foreach ( $settings ['tabs'] as $item ): ?>
                                        <div class="brand-img text-center">
                                            <img src="<?php print wp_kses_post($item['image']['url']); ?>" alt="">
                                        </div>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                            </div>
                            <div class="col-xl-3 col-lg-4 col-md-5">
                                <div class="bottom-social-icon text-md-right">
                                    <a href="<?php print wp_kses_post($settings['facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
                                    <a href="<?php print wp_kses_post($settings['twitter']); ?>"><i class="fab fa-twitter"></i></a>
                                    <a href="<?php print wp_kses_post($settings['linkedin']); ?>"><i class="fab fa-linkedin-in"></i></a>
                                    <a href="<?php print wp_kses_post($settings['youtube']); ?>"><i class="fab fa-youtube"></i></a>
                                    <a href="<?php print wp_kses_post($settings['behance']); ?>"><i class="fab fa-behance"></i></a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <!-- brand-area-end -->

<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
          $('.brand-active').owlCarousel({
		loop: true,
		nav: true,
		dots: false,

		navText: ['<i class="fas fa-angle-left"></i>', '<i class="fas fa-angle-right"></i>'],
		responsive: {
			0: {
				items: 1
			},
			576: {
				items: 1
			},
			768: {
				items: 1
			},
			992: {
				items: 3
			},
			1200: {
				items: 3
			}
		}
	})
        
        
    </script>   
    <?php } ?>
    <?php
    }

}