<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome2Faq extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-faq-home-2';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Faq Home-2', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Contact widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-form-horizontal';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Contact widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-2' ];
	}

	public function get_keywords() {
		return [ 'faq', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'FAQ', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'icon',
			[
				'label'   => esc_html__( 'icon', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);
			$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'background',
			[
				'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);


		$this->end_controls_section();

		    $this->start_controls_section(
      'section_content_item',
      [
        'label' => esc_html__( 'FAQ Items', 'bdevs-elementor' ),
      ]
    );
    $this->add_control(
      'tabs',
      [
        'label' => esc_html__( 'Items', 'bdevs-elementor' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => [ 

          [
            'name'        => 'title',
            'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'dynamic'     => [ 'active' => true ],
            'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
            'label_block' => true,
          ],

          [
            'name'        => 'description',
            'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
            'type'        => Controls_Manager::TEXTAREA,
            'dynamic'     => [ 'active' => true ],
            'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),
            'label_block' => true,
          ],

           [
            'name'        => 'address',
            'label'       => esc_html__( 'Address', 'bdevs-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'dynamic'     => [ 'active' => true ],
            'default'     => esc_html__( 'Address' , 'bdevs-elementor' ),
            'label_block' => true,
          ],


          [
            'name'        => 'target',
            'label'       => esc_html__( 'Target', 'bdevs-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'dynamic'     => [ 'active' => true ],
            'default'     => esc_html__( 'Target' , 'bdevs-elementor' ),
            'label_block' => true,
          ], 

          [
          	'name'        => 'area',
          	'label'       => esc_html__( 'Area', 'bdevs-elementor' ),
          	'type'        => Controls_Manager::TEXT,
          	'dynamic'     => [ 'active' => true ],
          	'default'     => esc_html__( 'Area' , 'bdevs-elementor' ),
          	'label_block' => true,
          ],                       

          [
          	'name'        => 'show',
          	'label'       => esc_html__( 'Show', 'bdevs-elementor' ),
          	'type'        => Controls_Manager::TEXT,
          	'dynamic'     => [ 'active' => true ],
          	'default'     => esc_html__( 'Show' , 'bdevs-elementor' ),
          	'label_block' => true,
          ],

           [
          	'name'        => 'true',
          	'label'       => esc_html__( 'Extend', 'bdevs-elementor' ),
          	'type'        => Controls_Manager::TEXT,
          	'dynamic'     => [ 'active' => true ],
          	'default'     => esc_html__( 'Extend' , 'bdevs-elementor' ),
          	'label_block' => true,
          ],

           [
          	'name'        => 'controls',
          	'label'       => esc_html__( 'Controls', 'bdevs-elementor' ),
          	'type'        => Controls_Manager::TEXT,
          	'dynamic'     => [ 'active' => true ],
          	'default'     => esc_html__( 'Controls' , 'bdevs-elementor' ),
          	'label_block' => true,
          ],

            [
          	'name'        => 'location',
          	'label'       => esc_html__( 'Location', 'bdevs-elementor' ),
          	'type'        => Controls_Manager::TEXT,
          	'dynamic'     => [ 'active' => true ],
          	'default'     => esc_html__( 'Location' , 'bdevs-elementor' ),
          	'label_block' => true,
          ],
            
      ],
  ]
);  
  $this->end_controls_section();  

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
            <!-- faq-area-start -->
            <div class="faq-area pt-120 pb-90">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 col-lg-6">
                            <div class="faq-box mb-30">
                                <div class="section-title section-title-cap mb-45">
                                    <div class="section-icon section1-icon">
                                        <img src="<?php print wp_kses_post($settings['icon']['url']); ?>" alt="">
                                    </div>
                                    <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                                    <p><?php print wp_kses_post($settings['content']); ?></p>
                                </div>
                                <div id="accordion" class="mt-40">
                                    <?php foreach ( $settings ['tabs'] as $item ): ?>
                                    <div class="card">
                                        <div class="card-header" id="<?php print wp_kses_post($item['address']); ?>">
                                            <h5 class="mb-0">
                                                <a href="#" class="<?php print wp_kses_post($item['area']); ?>" data-toggle="collapse" data-target="<?php print wp_kses_post($item['target']); ?>"
                                                    aria-expanded="<?php print wp_kses_post($item['true']); ?>" aria-controls="<?php print wp_kses_post($item['controls']); ?>">
                                                    <?php print wp_kses_post($item['title']); ?>
                                                </a>
                                            </h5>
                                        </div>

                                        <div id="<?php print wp_kses_post($item['location']); ?>" class="<?php print wp_kses_post($item['show']); ?>" aria-labelledby="<?php print wp_kses_post($item['address']); ?>" data-parent="#accordion">
                                            <div class="card-body">
                                                <p><?php print wp_kses_post($item['description']); ?></p>
                                            </div>
                                        </div>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-xl-6 col-lg-6">
                            <div class="faq-img mb-30">
                              <img class="bounce-animate" src="<?php print wp_kses_post($settings['background']['url']); ?>" alt="">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- faq-area-end -->
	<?php
	}

}