<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome2Slider extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-slider-home-2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Slider-Home-2', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-slides';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'home-2' ];
    }

    public function get_keywords() {
        return [ 'slider',];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_content_item_heading',
            [
                'label' => esc_html__( 'Slider', 'bdevs-elementor' ),
            ]
        ); 

         $this->add_control(
            'background',
            [
                'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );

        $this->end_controls_section();

            $this->start_controls_section(
            'section_content_items',
            [
                'label' => esc_html__( 'Slider Items', 'bdevs-elementor' ),
            ]
        );

        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items ', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [  

                  [
                    'name'    => 'image',
                    'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                    'type'    => Controls_Manager::MEDIA,
                    'dynamic' => [ 'active' => true ],
					'default'     => esc_html__( '' , 'bdevs-elementor' ),
                ],


                [
                  'name'        => 'subheading',
                  'label'       => esc_html__( 'Subheading', 'bdevs-elementor' ),
                  'type'        => Controls_Manager::TEXT,
                  'dynamic'     => [ 'active' => true ],
                  'default'     => esc_html__( 'Subheading' , 'bdevs-elementor' ),
                  'label_block' => true,
              ],

              [
                  'name'        => 'heading',
                  'label'       => esc_html__( 'Heading', 'bdevs-elementor' ),
                  'type'        => Controls_Manager::TEXT,
                  'dynamic'     => [ 'active' => true ],
                  'default'     => esc_html__( 'Heading' , 'bdevs-elementor' ),
                  'label_block' => true,
              ],    

              [
                  'name'        => 'link',
                  'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
                  'type'        => Controls_Manager::TEXT,
                  'dynamic'     => [ 'active' => true ],
                  'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                  'label_block' => true,
              ],

              [
                  'name'        => 'button',
                  'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
                  'type'        => Controls_Manager::TEXT,
                  'dynamic'     => [ 'active' => true ],
                  'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),
                  'label_block' => true,
              ],


                ],
            ]
        );

        $this->end_controls_section();  

        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        extract($settings);
        ?>
         <main>
            <!-- slider-start -->
            <div class="slider-area pos-relative">
                <div class="shape d-none d-xl-block">
               <div class="shape-item slider-01 bounce-animate"><img src="<?php print wp_kses_post($settings['background']['url']); ?>" alt=""></div>
                </div>
                <div class="slider-active">
                    <?php foreach ( $settings ['tabs'] as $item ): ?>       
                        <div class="single-slider slider-height d-flex align-items-center" data-background="<?php print wp_kses_post($item['image']['url']); ?>">
                            <div class="container">
                                <div class="row ">
                                    <div class="col-xl-8 col-lg-8">
                                        <div class="slider-content slider-text">
                                           <span data-animation="fadeInUp" data-delay=".3s"><?php print wp_kses_post($item['subheading']); ?></span>
                                           <h1 data-animation="fadeInUp" data-delay=".5s"><?php print wp_kses_post($item['heading']); ?></h1>
                                           <a class="btn" href="<?php print wp_kses_post($item['link']); ?>" data-animation="fadeInUp" data-delay=".7s"><?php print wp_kses_post($item['button']); ?></a>
                                       </div>
                                   </div>
                               </div>
                           </div>
                       </div>
                   <?php endforeach; ?>
               </div>
           </div>
           <!-- slider-start -->
			 <?php if (is_admin()) { ?>
    <script type="text/javascript">
    		$("[data-background]").each(function () {
	$(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
})
        
          function mainSlider() {
    var BasicSlider = $('.slider-active');
    BasicSlider.on('init', function (e, slick) {
        var $firstAnimatingElements = $('.single-slider:first-child').find('[data-animation]');
        doAnimations($firstAnimatingElements);
    });
    BasicSlider.on('beforeChange', function (e, slick, currentSlide, nextSlide) {
        var $animatingElements = $('.single-slider[data-slick-index="' + nextSlide + '"]').find('[data-animation]');
        doAnimations($animatingElements);
    });
    BasicSlider.slick({
        autoplay: false,
        autoplaySpeed: 10000,
        dots: false,
        fade: true,
		prevArrow: '<button type="button" class="slick-prev"> <i class="fas fa-angle-left"></i></button>',
		nextArrow: '<button type="button" class="slick-next"> <i class="fas fa-angle-right"></i></button>',
        arrows: true,
        responsive: [
            { breakpoint: 767, settings: { dots: false, arrows: false } }
        ]
    });

    function doAnimations(elements) {
        var animationEndEvents = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';
        elements.each(function () {
            var $this = $(this);
            var $animationDelay = $this.data('delay');
            var $animationType = 'animated ' + $this.data('animation');
            $this.css({
                'animation-delay': $animationDelay,
                '-webkit-animation-delay': $animationDelay
            });
            $this.addClass($animationType).one(animationEndEvents, function () {
                $this.removeClass($animationType);
            });
        });
    }
}
mainSlider();
        
        
    </script>   
    <?php } ?>
           <?php
       }

   }