<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsservicesPricing extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-pricing-services';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Pricing-Services', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Contact widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Contact widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'services'];
    }

    public function get_keywords() {
        return [ 'pricing',];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
    $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Video', 'bdevs-elementor' ),
            ]
        );

        $this->add_control(
            'background',
            [
                'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  

        $this->add_control(
            'video',
            [
                'label'       => __( 'Video', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('Video', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_content_item',
            [
                'label' => esc_html__( 'Pricing ', 'bdevs-elementor' ),
            ]
        ); 

        $this->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );


        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('This is Heading', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'content',
            [
                'label'       => __( 'Content', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'       => __('This is Content', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();



            $this->start_controls_section(
                'section_content_items',
                [
                    'label' => esc_html__( 'Pricing Items', 'bdevs-elementor' ),
                ]
            );

      $this->add_control(
          'tabs',
          [
              'label' => esc_html__( 'Items', 'bdevs-elementor' ),
              'type' => Controls_Manager::REPEATER,
              'fields' => [   

                 [
                    'name'    => 'image',
                    'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                    'type'    => Controls_Manager::MEDIA,
                    'dynamic' => [ 'active' => true ],
					 'default'     => esc_html__( '' , 'bdevs-elementor' ),
                ],

                [
                    'name'        => 'number',
                    'label'       => esc_html__( 'Number', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Number' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],


                [
                    'name'        => 'currency',
                    'label'       => esc_html__( 'Currency', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Currency' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],



                [
                    'name'        => 'title',
                    'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'subtitle',
                    'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],


                [
                    'name'        => 'popular',
                    'label'       => esc_html__( 'Popular', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Popular' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

           

                [
                    'name'        => 'organic',
                    'label'       => esc_html__( 'Organic', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Organic' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'organic_2',
                    'label'       => esc_html__( 'Organic 2', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Organic' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'organic_3',
                    'label'       => esc_html__( 'Organic 3', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Organic' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'organic_4',
                    'label'       => esc_html__( 'Organic', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Organic' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'organic_5',
                    'label'       => esc_html__( 'Organic 5', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Organic' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'organic_6',
                    'label'       => esc_html__( 'Organic 6', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Organic' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'link',
                    'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Link Button' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],

                [
                    'name'        => 'button',
                    'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
                    'type'        => Controls_Manager::TEXT,
                    'dynamic'     => [ 'active' => true ],
                    'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),
                    'label_block' => true,
                ],
                 
              ],
          ]
      );

      $this->end_controls_section();

        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
           
        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        extract($settings);
        ?>

        <!-- video-1-area-start -->
            <div class="video-1-area">
                <div class="container">
                    <div class="video-bg pt-260 pb-260" style="background-image:url(<?php print wp_kses_post($settings['background']['url']); ?>)">
                        <div class="row">
                            <div class="col-xl-12">
                                <div class="video-1-wrapper">
                                    <div class="video-1-icon text-center">
                                        <a class="popup-video" href="<?php print wp_kses_post($settings['video']); ?>"><i class="fa fa-play"></i></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- video-1-area-end -->
          <!-- pricing-area-start -->
            <div class="pricing-area grey1-bg pt-440 pb-90">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 col-lg-6 offset-lg-3 offset-xl-3">
                            <div class="section-title section-title-cap text-center mb-90">
                                <div class="section-icon section1-icon">
                                    <img src="<?php print wp_kses_post($settings['icon']['url']); ?>" alt="">
                                </div>
                                <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                                <p><?php print wp_kses_post($settings['content']); ?></p>
                            </div>
                        </div>
                    </div>
                    <div class="row">    
                <?php  $i=0;
                       foreach ( $settings['tabs'] as $item ):
                            $i++;
                            ?>
                            <?php if($i == 2){ ?>
                           <div class="col-xl-4 col-lg-4 col-md-6">
                            <div class="pricing-wrapper active mb-30">
                                <div class="pricing-top">
                                    <h4><?php print wp_kses_post($item['title']); ?></h4>
                                    <div class="price-count">
                                        <h1><span class="usd"><?php print wp_kses_post($item['currency']); ?></span><?php print wp_kses_post($item['number']); ?></h1>
                                    </div>
                                    <div class="pricing-text">
                                        <h5><?php print wp_kses_post($item['subtitle']); ?></h5>
                                    </div>
                                    <div class="pricing-icon">
                                        <img src="<?php print wp_kses_post($item['image']['url']); ?>" alt="">
                                    </div>
                                    <?php if ( '' !== $item['popular']): ?>
                                    <span class="populer-tag"><?php print wp_kses_post($item['popular']); ?></span>
                                      <?php endif; ?>
                                </div>
                                <ul class="pricing-list">
                                    <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic']); ?></li>
                                    <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic_2']); ?></li>
                                    <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic_3']); ?></li>
                                    <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic_4']); ?></li>
                                    <li><i class="dripicons-cross"></i><?php print wp_kses_post($item['organic_5']); ?></li>
                                    <li><i class="dripicons-cross"></i><?php print wp_kses_post($item['organic_6']); ?></li>
                                </ul>
                                <div class="pricing-button active">
                                    <a class="btn" href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['button']); ?></a>
                                </div>
                            </div>
                        </div>
                         <?php }else{ ?>
                         <div class="col-xl-4 col-lg-4 col-md-6">
                            <div class="pricing-wrapper mb-30">
                                <div class="pricing-top">
                                    <h4><?php print wp_kses_post($item['title']); ?></h4>
                                    <div class="price-count">
                                        <h1><span class="usd"><?php print wp_kses_post($item['currency']); ?></span><?php print wp_kses_post($item['number']); ?></h1>
                                    </div>
                                    <div class="pricing-text">
                                        <h5><?php print wp_kses_post($item['subtitle']); ?></h5>
                                    </div>
                                    <div class="pricing-icon">
                                        <img src="<?php print wp_kses_post($item['image']['url']); ?>" alt="">
                                    </div>
                                </div>
                                <ul class="pricing-list">
                                 <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic']); ?></li>
                                 <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic_2']); ?></li>
                                 <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic_3']); ?></li>
                                 <li><i class="dripicons-checkmark"></i><?php print wp_kses_post($item['organic_4']); ?></li>
                                 <li class="price-list"><i class="dripicons-cross"></i><?php print wp_kses_post($item['organic_5']); ?></li>
                                 <li class="price-list"><i class="dripicons-cross"></i><?php print wp_kses_post($item['organic_6']); ?></li>
                                </ul>
                                <div class="pricing-button">
                                    <a class="btn" href="<?php print wp_kses_post($item['link']); ?>"><?php print wp_kses_post($item['button']); ?></a>
                                </div>
                            </div>
                        </div>
                      <?php } ?>  
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
            <!-- pricing-area-end -->
    <?php
    }

}